library(shiny)

shinyServer(function(input, output,session) {

   data <- reactive({
        x <- matrix(rnorm(input$n*2*1e3,input$mu,input$sigma),nrow=2*1e3)
        xbar <- apply(x,1,mean)    
        s <- apply(x,1,sd)    
        z <- sqrt(input$n)*(xbar-10)/s
        2*(1-pt(abs(z),input$n-1))
   })     
   

   output$text2 <- renderText({
      n <- input$n
      al <- as.numeric(input$alpha)
      cl <- round(qt(1-al/2,input$n-1),3)      
      line <- paste("<h4> &alpha;  = ",input$alpha,"</h4>",sep="")
      line[2] <- paste("<h4> H<sub>0</sub>: &mu;  = 10</h4>",sep="")
      line[3] <- paste("<h4> H<sub>a</sub>: &mu; &ne; 10</h4>",sep="")
      line[4] <-"<hr>"

      for(i in 0:input$step) {
        if(i>0) {
            x <- round(sort(rnorm(n,input$mu,input$sigma)),2)
            xbar <- round(mean(x),3)
            s <- round(sd(x),3)
            line[5] <- "<h4>Ordered Data:</h4>"
            line[6] <- paste("<h5>  ",paste(x,collapse=" "),"</h4>",sep=" ")
            line[7] <-"<hr>"
            T <- round(sqrt(n)*(xbar-10)/s,3)
            pv <- 2*pt(-abs(T),n-1) 
            sgn <- ifelse(pv>al," > "," < ") 
            line[8] <- paste("<h4>p-value = ",round(pv,4),sgn," &alpha; </h4>",sep="")    
            line[9] <- paste("<h4>so we ",ifelse(abs(T)>cl," reject "," fail to reject "), " the null hypothesis</h4>",sep="")
         }   
      }
      line
   })
    
   output$text1 <- renderText({
      x <- data()
      al <- as.numeric(input$alpha)
      z <- round(sum(x<al)/length(x)*100,1)
      red <- paste("<font color=\"red\">")
      blue <- paste("<font color=\"blue\">")
      line <- paste("<h4>Percentage of rejected null hypotheses (in red):",z,"%</h4>")
      if(input$mu==10) line[2] <- HTML(paste("<h4>",blue,"&mu; = 10.0, so Null Hypothesis is true!</font></h4>"))
      else line[2] <- HTML(paste("<h4>",red,"&mu; = ",input$mu," &ne; 10.0, so Null Hypothesis is false!</font></h4>"))
      line
   })        
   
    
   output$plot1 <- renderPlot({
        x <- data()
        al <- as.numeric(input$alpha)
        brks <- hist(x,200,plot=F)$breaks
        hist(x,breaks=brks,xlab="p-value",ylab="",main="")
        hist(x[x<al],breaks=brks,add=T,col="red")    
   })
           
   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#pvalue\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 11/226/2014</h6>")
      
  })    
  output$explainText <- renderText({ 
        "<h5>We generate n observations from a normal distribution with mean &mu; and standard deviation 1.</h5>
         <h5>We then carry out a test of H<sub>0</sub>: &mu;=10 vs H<sub>a</sub>: &mu;&ne;10 and record the p-value.</h5>
         <h5>This is repeated 1000 times. We draw a histogram of the p-values and find the percentage of simulation runs with p&lt;&alpha;.</h5>
         <h5>If the test works as it should and if &mu;=10.0 the percentage should 100&alpha;%.</h5>
         <h5> As &mu; goes farther away from 10.0 the percentage should grow to 100%. </h5>"
  })

})

